@@ -14,7 +14,7 @@ class File(BaseModel):
 
     @classmethod
     async def afrom_path(cls, path: str):
-        await asyncio.to_thread(cls.from_path, path)
+        return await asyncio.to_thread(cls.from_path, path)
 
     @classmethod
     def from_url(cls, url: str):
@@ -38,7 +38,7 @@ class File(BaseModel):
     async def asave(self, path: str):
         await asyncio.to_thread(self.save, path)
 
-    def show_image(self):
+    def get_image(self):
         try:
             from PIL import Image  # type: ignore
         except ImportError:
@@ -56,6 +56,11 @@ class File(BaseModel):
         if img.mode not in ('RGB', 'L'):  # L is for greyscale images
             img = img.convert('RGB')
 
+        return img
+
+    def show_image(self):
+        img = self.get_image()
+
         # Display the image
         try:
             # Try to get the IPython shell if available.
